from setuptools import setup, find_packages

setup(
    name='actionsBy',
    version='1.0.1',
    description='This package contains the base file where we can perform the click, displayed, sendkeys using any locators like id, name, xpath by just pass the parameters to the function',
    author='Jagadeesh',
    author_email='jagadeeshsaratha@gmail.com',
    packages=find_packages(),
)
